<?php
/**
*
* ucp [Português]
*
* @package language
* @version 1.0.9
* @Traduzido por: http://phpbbportugal.com - segundo as normas do Acordo Ortográfico
* @copyright (c) 2005 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
* 
*/

/**
* DO NOT CHANGE
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

if (empty($lang) || !is_array($lang))
{
	$lang = array();
}

// DEVELOPERS PLEASE NOTE
//
// All language files should use UTF-8 as their encoding and the files must not contain a BOM.
//
// Placeholders can now contain order information, e.g. instead of
// 'Page %s of %s' you can (and should) write 'Page %1$s of %2$s', this allows
// translators to re-order the output of data while ensuring it remains correct
//
// You do not need this where single placeholders are used, e.g. 'Message %d' is fine
// equally where a string contains only two placeholders which are used to wrap text
// in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine

// Privacy policy and T&C
$lang = array_merge($lang, array(
	'TERMS_OF_USE_CONTENT'				=> 'Ao entrar em “%1$s” (doravante “nós”, “nosso”, “%1$s”, “%2$s”), concorda sujeitar-se aos termos seguintes. Se não concorda em sujeitar-se aos termos seguintes, por favor não entre e/ou utilize “%1$s”. Nós podemos mudar estes termos a qualquer momento e vamos fazer o nosso melhor para mantê-lo informado. No entanto, seria prudente rever regularmente estes termos. O uso continuado de “%1$s” significa que concorda em ser legalmente sujeito a estes termos quando são atualizados e/ou alterados.<br />
	<br />
	Os nossos Fóruns são desenvolvidos pelo phpBB (doravante “eles”, “software phpBB”, “www.phpbb.com”, “Grupo phpBB”, “Equipa phpBB”) que é um sistema de comunidades virtuais sujeito à “<a href="http://opensource.org/licenses/gpl-license.php">GNU General Public License v2</a>” (doravante “GPL”) que pode ser transferido a partir de <a href="https://www.phpbb.com/">www.phpbb.com</a>. O software phpBB apenas facilita discussões através da internet. O Grupo phpBB não é responsável pelo conteúdo que nós permitimos e/ou impedimos e/ou pela conduta permitida. Para mais informações sobre o phpBB, consulte: <a href="https://www.phpbb.com/">https://www.phpbb.com/</a>.<br />
	<br />
	Compromete-se a não colocar qualquer mensagem abusiva, obscena, vulgar, insultuosa, de ódio, ameaçadora, sexualmente tendenciosa ou qualquer outro material que possa violar qualquer lei seja de seu país, o país onde “%1$s” está alojado ou lei Internacional. Fazer isso pode levar você será diretamente e permanentemente banido, com notificação de seu Internet Service Provider, se for considerado necessário por nós. O endereço IP de todas as mensagens são registrados para ajudar a implementar essas condições. Você concorda que “%1$s” tem o direito de remover, editar, mover ou encerrar qualquer tópico em qualquer momento que se ver necessário. Como utilizador aceita que as informações que forneceu acima sejam guardadas numa Base de Dados. Apesar desta informação não ser divulgada a terceiros sem o seu consentimento, o “%1$s” ou o phpBB não podem ser responsabilizados por qualquer atentado Hacker, que possam expor essa informação.',
	'PRIVACY_POLICY'					=> 'Esta política explica em detalhe como “%1$s” juntamente com suas empresas afiliadas (doravante "nós", "nosso", “%1$s”, “%2$s”) e o phpBB (doravante “eles”, “phpBB software”, “www.phpbb.com”, “Grupo phpBB”, “Equipas phpBB”) utilizam a informação recolhida durante as suas sessões de online (doravante denominada “a sua informação”).<br />
	<br />
	Recolheremos informações suas de duas formas. A primeira, ao navegar no“%1$s” fará com que o Software phpBB crie cookies que são pequenos ficheiros de texto, transferidos temporariamente pelos navegadores web para o seu computador. Os dois primeiros cookies têm a identificação do utilizador (doravante denominado “user-id”) e um identificador de sessão anónima (doravante “session-id”), assinado automaticamente para si pelo software phpBB. O terceiro cookie será criado sempre que tenha tópicos lidos em “%1$s” e é usado para registar os tópicos lidos, aumentando assim sua experiência como utilizador.<br />
	<br />
	Podem também ser criados cookies externos ao software phpBB enquanto navegar no “%1$s”, ainda que estes sejam externos o âmbito destes cookies é proteger as páginas criadas pelo Software phpBB. A segunda maneira de recolher informações suas é através das mensagens que partilha connosco. Esta recolha pode fazer-se mas não está limitada a: mensagens enquanto utilizador anónimo (doravante “anonymous posts”), registando-se em “%1$s” (doravante denominado “a sua conta”) e através das mensagens enviadas por si depois do registro e quando ligado (doravante “as suas mensagens”).<br />
	<br />
	Sua conta deverá ter no mínimo um nome único (doravante “your user name”), uma senha pessoal utilizada para entrar na sua conta (doravante, “your password”) e um endereço pessoal de email válido (doravante “your email”). As informações da sua conta em “%1$s” são protegidas pelas leis de proteção de dados aplicáveis no nosso país. Qualquer outra informação além do seu nome de utilizador, da sua senha e do seu endereço de email solicitados pelo “%1$s” durante o processo de registro, é obrigatória ou opcional, segundo o critério do “%1$s”. Em todos os casos, tem a opção de escolher as informações da sua conta que serão publicadas. Além disso, dentro da sua conta, pode optar por receber ou não receber os emails gerados automaticamente pelo software phpBB.<br />
	<br />
	A sua senha é encriptada (a one-way hash) para que seja segura. No entanto, recomendamos que não utilize a mesma senha em vários sítios diferentes. A senha é um meio para entrar na sua conta em “%1$s”, então por favor guarde-a com cuidado e em nenhuma circunstância alguém relacionado com “%1$s”, phpBB ou um terceiro, tem legitimidade para lhe pedir a senha. Se esquecer a senha da sua conta, pode usar a opção “Esqueci-me da senha” oferecida pelo software phpBB. Este processo pede-lhe o nome de utilizador e email, para o phpBB gerar uma nova senha e reativar o seu registo.<br />
	',
)); 


// Common language entries 
$lang = array_merge($lang, array( 
	'ACCOUNT_ACTIVE'					=> 'O seu Registo foi ativado.',
	'ACCOUNT_ACTIVE_ADMIN'				=> 'O seu Registo foi ativado.',
	'ACCOUNT_ACTIVE_PROFILE'			=> 'A sua conta foi reativada com sucesso.',
	'ACCOUNT_ADDED'						=> 'Obrigado por Registar-se, a sua conta foi criada. Já pode entrar com o seu nome de Utilizador e Senha.',
	'ACCOUNT_COPPA'						=> 'A sua conta foi criada. Para ser Aprovada é necessário a autorização do seu Encarregado de Educação. Para mais detalhes verifique seu o email.',
	'ACCOUNT_EMAIL_CHANGED'				=> 'A sua conta foi atualizada. Neste Fórum as alterações de email requerem a reativação. A chave de ativação foi enviada para o seu novo endereço de email. Para mais detalhes verifique seu o email.',
	'ACCOUNT_EMAIL_CHANGED_ADMIN'		=> 'A sua conta foi atualizada. Neste Fórum as alterações de email requerem a reativação por um administrador. Receberá um email quando a sua conta for reativada.',
	'ACCOUNT_INACTIVE'					=> 'A sua conta foi criada com sucesso. A Chave de Ativação foi enviada para o endereço de email que indicou durante o seu Registo. Ao receber o email proceda à Ativação da sua conta. Só então poderá entrar no Fórum.',
	'ACCOUNT_INACTIVE_ADMIN'			=> 'A sua conta foi criada. Neste Fórum a ativação da conta é feita pelo Administrador. Foi enviado um email ao Administrador que o informará quando Ativar sua conta. Mantenha-se atento ao seu email.',
	'ACTIVATION_EMAIL_SENT'				=> 'O email de ativação foi enviado para o seu endereço de email.',
	'ACTIVATION_EMAIL_SENT_ADMIN'		=> 'O email de ativação foi enviado para o Adminstrador.',
	'ADD'								=> 'Adicionar',
	'ADD_BCC'							=> 'Adicionar [B]',
	'ADD_FOES'							=> 'Adicionar novo Inimigo',
	'ADD_FOES_EXPLAIN'					=> 'Pode introduzir vários Utilizadores, um por linha.',
	'ADD_FOLDER'						=> 'Adicionar Pasta',
	'ADD_FRIENDS'						=> 'Adicionar um novo Amigo',
	'ADD_FRIENDS_EXPLAIN'				=> 'Pode introduzir vários Utilizadores, um por linha.',
	'ADD_NEW_RULE'						=> 'Adicionar nova Regra',
	'ADD_RULE'							=> 'Adicionar Regra',
	'ADD_TO'							=> 'Adicionar [Para]',
	'ADD_USERS_UCP_EXPLAIN'				=> 'Aqui pode adicionar novos utilizadores ao grupo. Pode selecionar se este grupo se torna o novo padrão para os utilizadores selecionados. Por favor, digite um nome de utilizador por cada linha.',
	'ADMIN_EMAIL'						=> 'Autorizar os Administradores a enviarem-me emails',
	'AGREE'								=> 'Li e concordo com todas as condições',
	'ALLOW_PM'							=> 'Autorizar o envio de Mensagens Privadas',
	'ALLOW_PM_EXPLAIN'					=> 'Administradores/Moderadores podem sempre enviar-lhe Mensagens Privadas.',
	'ALREADY_ACTIVATED'					=> 'O seu registo já foi ativado.',
	'ATTACHMENTS_EXPLAIN'				=> 'Esta é uma lista dos anexos que enviou para este Fórum.',
	'ATTACHMENTS_DELETED'				=> 'Anexos Apagados.',
	'ATTACHMENT_DELETED'				=> 'Anexo Apagado.',
	'AVATAR_CATEGORY'					=> 'Categoria',
	'AVATAR_EXPLAIN'					=> 'Dimensões máximas; aargura: %1$d pixels, altura: %2$d pixels, tamanho do ficheiro: %3$.2f KiB.',
	'AVATAR_FEATURES_DISABLED'			=> 'A função de Avatar está desativada.',
	'AVATAR_GALLERY'					=> 'Galeria Local',
	'AVATAR_GENERAL_UPLOAD_ERROR'		=> 'Não foi possível enviar o Avatar para %s.',
	'AVATAR_NOT_ALLOWED'				=> 'O seu avatar não pode ser exibido porque os avatares foram desativados.',
	'AVATAR_PAGE'						=> 'Página',
	'AVATAR_TYPE_NOT_ALLOWED'			=> 'O seu Avatar atual não pode ser exibido porque o seu tipo foi desativado.',

	'BACK_TO_DRAFTS'					=> 'Voltar aos rascunhos arquivados',
	'BACK_TO_LOGIN'						=> 'Entrar',
	'BIRTHDAY'							=> 'Aniversário',
	'BIRTHDAY_EXPLAIN'					=> 'O seu aniversário será assinalado na data indicada.',
	'BOARD_DATE_FORMAT'					=> 'O meu formato de data',
	'BOARD_DATE_FORMAT_EXPLAIN'			=> 'A sintaxe usada é idêntica à função PHP <a href="http://www.php.net/date">date()</a>.',
	'BOARD_DST'							=> 'Ativar Horário de Verão',
	'BOARD_LANGUAGE'					=> 'O meu idioma',
	'BOARD_STYLE'						=> 'O Estilo do meu Painel',
	'BOARD_TIMEZONE'					=> 'O meu Fuso Horário',
	'BOOKMARKS'							=> 'Favoritos',
	'BOOKMARKS_EXPLAIN'					=> 'Esta é a sua lista de Favoritos. Para remover da lista um Favorito, selecione a caixa correspondente e carregue no botão Apagar Favoritos Marcados.',
	'BOOKMARKS_DISABLED'				=> 'Favoritos foram desativados.',
	'BOOKMARKS_REMOVED'					=> 'Os Favoritos selecionados foram apagados com sucesso.',

	'CANNOT_EDIT_MESSAGE_TIME'			=> 'Não pode editar ou apagar a mensagem.',
	'CANNOT_MOVE_TO_SAME_FOLDER'		=> 'Não podem ser movidas mensagens da pasta que quer Apagar.',
	'CANNOT_MOVE_FROM_SPECIAL'			=> 'Não podem ser movidas mensagens da pasta de saida.',
	'CANNOT_RENAME_FOLDER'				=> 'Esta pasta não pode ser renomeada.',
	'CANNOT_REMOVE_FOLDER'				=> 'Esta pasta não pode ser apagada.',
	'CHANGE_DEFAULT_GROUP'				=> 'Alterar Grupo Padrão',
	'CHANGE_PASSWORD'					=> 'Alterar Senha',
	'CLICK_GOTO_FOLDER'					=> '%1$sVá para a “%3$s” pasta%2$s',
	'CLICK_RETURN_FOLDER'				=> 'Clique %1$sAqui%2$s para voltar para a pasta %3$s',
	'CONFIRMATION'						=> 'Confirmação de Registo',
	'CONFIRM_CHANGES'					=> 'Confirmar Alterações',
	'CONFIRM_EMAIL'						=> 'Confirme o endereço de email',
	'CONFIRM_EMAIL_EXPLAIN'				=> 'Só se alterar o seu endereço de email.',
	'CONFIRM_EXPLAIN'					=> 'Para prevenir Registos automáticos de "espiões" é necessário introduzir um código de confirmação. O código é exibido na imagem que deverá ver em baixo. Se tem alguma deficiência visual, e não pode ler o código, por favor, contate o %sAdministrador do Fórum%s.',
	'VC_REFRESH'						=> 'Alterar Código de Confirmação',
	'VC_REFRESH_EXPLAIN'				=> 'Se não consegue ler o código pode pedir um novo clicando no botão.',
	
	'CONFIRM_PASSWORD'					=> 'Confirme a sua Senha',
	'CONFIRM_PASSWORD_EXPLAIN'			=> 'Só se alterar a Senha atual.',
	'COPPA_BIRTHDAY'					=> 'Neste Fórum o Registo de Utilizadores menores de 13 anos necessita da Aprovação do Encarregado de Educação. Se tem menos de 13 anos o Registo só será Aprovado pelo Administrador do Fórum depois do seu Encarregado de Educação enviar a autorização para a sua participação. Para continuar com o Registo, selecione a opção correta, de acordo com a sua idade.',
	'COPPA_COMPLIANCE'					=> 'De acordo com a COPPA',
	'COPPA_EXPLAIN'						=> 'Ao clicar em enviar, criará a sua conta. No entanto, só será ativada quando o seu Encarregado de Educação ou o responsável legal autorizar a sua participação no Fórum. Para isso receberá um email com mais detalhes.',
	'CREATE_FOLDER'						=> 'Adicionar Pasta',
	'CURRENT_IMAGE'						=> 'Imagem Atual',
	'CURRENT_PASSWORD'					=> 'Senha Atual',
	'CURRENT_PASSWORD_EXPLAIN'			=> 'Para alterar o seu endereço de email ou nome de utilizador, tem que inserir a sua senha atual.',
	'CURRENT_CHANGE_PASSWORD_EXPLAIN'	=> 'Para alterar a senha, o endereço de email ou o seu nome de utilizador, tem que inserir a sua senha atual.',
	'CUR_PASSWORD_EMPTY'				=> 'Não digitou a senha atual.',
	'CUR_PASSWORD_ERROR'				=> 'A Senha atual que escreveu está incorreta.',
	'CUSTOM_DATEFORMAT'					=> 'Personalizar',

	'DEFAULT_ACTION'					=> 'Ação Padrão',
	'DEFAULT_ACTION_EXPLAIN'			=> 'Esta ação será ativada se nenhuma das anteriores forem aplicáveis.',
	'DEFAULT_ADD_SIG'					=> 'Ativar sempre a minha Assinatura',
	'DEFAULT_BBCODE'					=> 'Ativar sempre o BBCode',
	'DEFAULT_NOTIFY'					=> 'Avisar-me sempre que houver respostas novas',
	'DEFAULT_SMILIES'					=> 'Ativar sempre as Emoções',
	'DEFINED_RULES'						=> 'Regras Definidas',
	'DELETED_TOPIC'						=> 'O Tópico selecionado foi apagado com sucesso.',
	'DELETE_ATTACHMENT'					=> 'Apagar Anexo',
	'DELETE_ATTACHMENTS'				=> 'Apagar Anexos',
	'DELETE_ATTACHMENT_CONFIRM'			=> 'Tem a certeza que deseja remover este anexo?',
	'DELETE_ATTACHMENTS_CONFIRM'		=> 'Tem a certeza que deseja remover estes anexos?',
	'DELETE_AVATAR'						=> 'Apagar Imagem',
	'DELETE_COOKIES_CONFIRM'			=> 'Apagar todos os cookies?',
	'DELETE_MARKED_PM'					=> 'Apagar as Mensagens selecionadas',
	'DELETE_MARKED_PM_CONFIRM'			=> 'Tem a certeza de que deseja apagar as Mensagens selecionadas?',
	'DELETE_OLDEST_MESSAGES'			=> 'Apagar as Mensagens antigas ',
	'DELETE_MESSAGE'					=> 'Apagar a Mensagem',
	'DELETE_MESSAGE_CONFIRM'			=> 'Tem a certeza de que deseja apagar esta Mensagem Privada?',
	'DELETE_MESSAGES_IN_FOLDER'			=> 'Apagar todas as Mensagens dentro de pasta removida',
	'DELETE_RULE'						=> 'Apagar Regra',
	'DELETE_RULE_CONFIRM'				=> 'Tem a certeza de que deseja Apagar está regra?',
	'DEMOTE_SELECTED'					=> 'Remover o selecionado',
	'DISABLE_CENSORS'					=> 'Permitir Palavras Censuradas',
	'DISPLAY_GALLERY'					=> 'Mostrar Galeria',
	'DOMAIN_NO_MX_RECORD_EMAIL'			=> 'O Domínio do endereço de email indicado é inválido.',
	'DOWNLOADS'							=> 'Transferências',
	'DRAFTS_DELETED'					=> 'Todos os rascunhos selecionadas foram apagados.',
	'DRAFTS_EXPLAIN'					=> 'Aqui pode ver, editar e apagar os rascunhos arquivados.',
	'DRAFT_UPDATED'						=> 'Rascunhos atualizados.',

	'EDIT_DRAFT_EXPLAIN'				=> 'Aqui pode editar seu rascunho. Rascunhos não contêm anexos e informações de votações.',
	'EMAIL_BANNED_EMAIL'				=> 'Não é permitido utilizar o endereço de email indicado.',

	'EMAIL_REMIND'						=> 'Este deve ser o endereço de email que indicou ao registar-se.',
	'EMAIL_TAKEN_EMAIL'					=> 'Este endereço de email já está em uso.',
	'EMPTY_DRAFT'						=> 'Deve escrever uma mensagem antes de enviar as suas alterações.',
	'EMPTY_DRAFT_TITLE'					=> 'O Rascunho tem que ter um Título.',
	'EXPORT_AS_XML'						=> 'Exportar em XML',
	'EXPORT_AS_CSV'						=> 'Exportar em CSV',
	'EXPORT_AS_CSV_EXCEL'				=> 'Exportar em CSV (Excel)',
	'EXPORT_AS_TXT'						=> 'Exportar em TXT',
	'EXPORT_AS_MSG'						=> 'Exportar em MSG',
	'EXPORT_FOLDER'						=> 'Exportar Pasta',

	'FIELD_REQUIRED'					=> 'O Campo “%s” deve ser preenchido.',
	'FIELD_TOO_SHORT'					=> 'O Campo "%1$s" é muito curto. O mínimo de caracteres é de %2$d.',
	'FIELD_TOO_LONG'					=> 'O Campo "%1$s" é muito longo. O máximo de caracteres permitidos são %2$d.',
	'FIELD_TOO_SMALL'					=> 'O Valor de "%1$s" é muito pequeno. O valor mínimo é de %2$d.',
	'FIELD_TOO_LARGE'					=> 'O Valor de "%1$s" é muito grande. O valor máximo é de %2$d.',
	'FIELD_INVALID_CHARS_NUMBERS_ONLY'	=> 'O Campo “%s” tem caracteres inválidos. São permitidos somente números.',
	'FIELD_INVALID_CHARS_ALPHA_ONLY'	=> 'O Campo “%s” tem caracteres inválidos. São permitidos somente caracteres alfanuméricos.',
	'FIELD_INVALID_CHARS_SPACERS_ONLY'	=> 'O Campo “%s” tem caracteres inválidos. Somente alfanumérico, espaço ou - +_ [] são permitidos.',
	'FIELD_INVALID_DATE'				=> 'O Campo “%s” tem uma data inválida.',
	'FIELD_INVALID_VALUE'				=> 'O Campo “%s” um valor inválido.',

	'FOE_MESSAGE'						=> 'Mensagem de um Inimigo',
	'FOES_EXPLAIN'						=> 'Inimigos são Utilizadores que serão ignorados. As Mensagens destes Utilizadores não serão totalmente visíveis e as Mensagens Privadas não são autorizadas. No entanto não pode ignorar Administradores ou Moderadores.',
	'FOES_UPDATED'						=> 'A sua Lista de Inimigos foi atualizada com sucesso.',
	'FOLDER_ADDED'						=> 'A Pasta foi adicionada com sucesso.',
	'FOLDER_MESSAGE_STATUS'				=> '%1$d Mensagens de %2$d armazenadas ',
	'FOLDER_NAME_EMPTY'					=> 'Deve escrever um nome para esta pasta.',
	'FOLDER_NAME_EXIST'					=> 'A Pasta %s já existe.',
	'FOLDER_OPTIONS'					=> 'Opções de Pasta',
	'FOLDER_RENAMED'					=> 'A Pasta foi renomeada com sucesso.',
	'FOLDER_REMOVED'					=> 'A Pasta foi apagada com sucesso.',
	'FOLDER_STATUS_MSG'					=> 'A Pasta está %1$d%% cheia (%2$d mensagens de %3$d arquivadas)',
	'FORWARD_PM'						=> 'Próxima MP',
	'FORCE_PASSWORD_EXPLAIN'			=> 'Antes de continuar, é necessário alterar a sua senha.',
	'FRIEND_MESSAGE'					=> 'Mensagem de um Amigo',
	'FRIENDS'							=> 'Amigos',
	'FRIENDS_EXPLAIN'					=> 'Os Amigos permitem o acesso rápido aos Utilizadores com quem comunica frequentemente. As Mensagens dos Amigos só serão destacadas se o Template do Fórum o permitir.',
	'FRIENDS_OFFLINE'					=> 'Desligado',
	'FRIENDS_ONLINE'					=> 'Ligado',
	'FRIENDS_UPDATED'					=> 'A sua Lista de Amigos foi atualizada com sucesso.',
	'FULL_FOLDER_OPTION_CHANGED'		=> 'Opções de Pasta cheia alteradas com sucesso.',
	'FWD_ORIGINAL_MESSAGE'				=> '-------- Mensagem Original --------',
	'FWD_SUBJECT'						=> 'Título: %s',
	'FWD_DATE'							=> 'Data: %s',
	'FWD_FROM'							=> 'De: %s',
	'FWD_TO'							=> 'Para: %s',

	'GLOBAL_ANNOUNCEMENT'				=> 'Anúncio Global',

	'HIDE_ONLINE'						=> 'Ocultar o meu Status Ligado',
	'HIDE_ONLINE_EXPLAIN'				=> 'Ficará invisível na próxima visita ao Fórum.',
	'HOLD_NEW_MESSAGES'					=> 'Não serão aceitas novas Mensagens (As Mensagens novas serão mantidas até haver espaço disponível)',
	'HOLD_NEW_MESSAGES_SHORT'			=> 'Manter as Mensagens novas',

	'IF_FOLDER_FULL'					=> 'Se a Pasta estiver cheia',
	'IMPORTANT_NEWS'					=> 'Anúncios Importantes',
	'INVALID_USER_BIRTHDAY'				=> 'A data de nascimento não é válida.',
	'INVALID_CHARS_USERNAME'			=> 'O Nome de utilizador contém caracteres proibidos.',
	'INVALID_CHARS_NEW_PASSWORD'		=> 'A Senha não caracteres exigidos.',
	'ITEMS_REQUIRED'					=> 'Os itens marcados com * são campos de preenchimento obrigatório.',

	'JOIN_SELECTED'						=> 'Aderir ao selecionado',

	'LANGUAGE'							=> 'Idioma',
	'LINK_REMOTE_AVATAR'				=> 'Atalho Remoto',
	'LINK_REMOTE_AVATAR_EXPLAIN'		=> 'Indique a URL do local que contém a imagem de Avatar que deseja.',
	'LINK_REMOTE_SIZE'					=> 'Dimensões do Avatar',
	'LINK_REMOTE_SIZE_EXPLAIN'			=> 'Especifique a Largura e Altura do Avatar. Deixe espaço em branco para tentar a verificação automática.',
	'LOGIN_EXPLAIN_UCP'					=> 'Tem que estar ligado para entrar no Painel de Controlo do Utilizador.',
	'LOGIN_REDIRECT'					=> 'A sua sessão foi iniciada.',
	'LOGOUT_FAILED'						=> 'A sua sessão não foi encerrada. Se continuar tendo este problema contate um Administrador.',
	'LOGOUT_REDIRECT'					=> 'A sua sessão foi encerrada.',

	'MARK_IMPORTANT'					=> 'Marcar/Desmarcar como Importante',
	'MARKED_MESSAGE'					=> 'Mensagem Marcada',
	'MAX_FOLDER_REACHED'				=> 'Foi atingido o número máximo de pastas permitidas aos Utilizadores.',
	'MESSAGE_BY_AUTHOR'					=> 'por',
	'MESSAGE_COLOURS'					=> 'Cores da Mensagem',
	'MESSAGE_DELETED'					=> 'A Mensagem selecionada foi apagada com sucesso.',
	'MESSAGE_EDITED'					=> 'Mensagem editada com sucesso.',
	'MESSAGE_HISTORY'					=> 'Histórico de Mensagens',
	'MESSAGE_REMOVED_FROM_OUTBOX'		=> 'Esta mensagem foi apagada pelo autor.',
	'MESSAGE_SENT_ON'					=> 'em',
	'MESSAGE_STORED'					=> 'A Mensagem foi enviada com sucesso.',
	'MESSAGE_TO'						=> 'Para',
	'MESSAGES_DELETED'					=> 'Mensagens apagada',
	'MOVE_DELETED_MESSAGES_TO'			=> 'Mover mensagens da pasta apagada para',
	'MOVE_DOWN'							=> 'Mover - Baixo',
	'MOVE_MARKED_TO_FOLDER'				=> 'Mover selecionados para %s',
	'MOVE_PM_ERROR'						=> 'Um erro ocorreu enquanto as mensagens eram movidas para a nova pasta. Por isso, foram movidas somente as Mensagens %1$d de %2$d.',
	'MOVE_TO_FOLDER'					=> 'Mover para a Pasta',
	'MOVE_UP'							=> 'Mover - Cima',

	'NEW_EMAIL_CONFIRM_EMPTY'			=> 'Não digitou o email de confirmação.',
	'NEW_EMAIL_ERROR'					=> 'Os endereços de email indicados são diferentes.',
	'NEW_FOLDER_NAME'					=> 'Nome da nova Pasta',
	'NEW_PASSWORD'						=> 'Nova Senha',
	'NEW_PASSWORD_CONFIRM_EMPTY'		=> 'Não digitou a Senha de confirmação.',
	'NEW_PASSWORD_ERROR'				=> 'As Senhas indicadas são diferentes.',
	'NOTIFY_METHOD'						=> 'Método de Aviso',
	'NOTIFY_METHOD_BOTH'				=> 'Ambos',
	'NOTIFY_METHOD_EMAIL'				=> 'Somente email',
	'NOTIFY_METHOD_EXPLAIN'				=> 'Método para enviar Mensagens enviadas por este painel.',
	'NOTIFY_METHOD_IM'					=> 'Apenas Jabber',
	'NOTIFY_ON_PM'						=> 'Avisar-me por email de novas Mensagens Privadas',
	'NOT_ADDED_FRIENDS_ANONYMOUS'		=> 'Não pode adicionar um Visitante à sua Lista de Amigos.',
	'NOT_ADDED_FRIENDS_BOTS'			=> 'Não pode adicionar Motores de Busca à sua lista de amigos.',
	'NOT_ADDED_FRIENDS_FOES'			=> 'Não pode adicionar Inimigos à sua Lista de Amigos.',
	'NOT_ADDED_FRIENDS_SELF'			=> 'Não pode auto adicionar-se à sua Lista de Amigos.',
	'NOT_ADDED_FOES_MOD_ADMIN'			=> 'Não pode adicionar Administradores ou Moderadores à sua Lista de Inimigos.',
	'NOT_ADDED_FOES_ANONYMOUS'			=> 'Não pode adicionar um Visitante à sua Lista de Inimigos.',
	'NOT_ADDED_FOES_BOTS'				=> 'Não pode adicionar Motores de Busca à sua lista de inimigos.',
	'NOT_ADDED_FOES_FRIENDS'			=> 'Não pode adicionar Amigos à sua Lista de Inimigos.',
	'NOT_ADDED_FOES_SELF'				=> 'Não pode auto adicionar-se à sua Lista de Inimigos.',
	'NOT_AGREE'							=> 'Li e não concordo com estas condições',
	'NOT_ENOUGH_SPACE_FOLDER'			=> 'A Pasta de Destino “%s” parece estar cheia. O seu pedido não foi executado.',
	'NOT_MOVED_MESSAGE'					=> 'Tem 1 Mensagem Privada presa, porque sua pasta está cheia.',
	'NOT_MOVED_MESSAGES'				=> 'Tem %d Mensagens Privadas presas, porque sua pasta está cheia.',
	'NO_ACTION_MODE'					=> 'Não foi selecionada uma ação para esta Mensagem.',
	'NO_AUTHOR'							=> 'Nenhum Autor definido para esta Mensagem',
	'NO_AVATAR_CATEGORY'				=> 'Nenhum',

	'NO_AUTH_DELETE_MESSAGE'			=> 'Apagar Mensagens Privadas: Proibido.',
	'NO_AUTH_EDIT_MESSAGE'				=> 'Editar Mensagens Privadas: Proibido.',
	'NO_AUTH_FORWARD_MESSAGE'			=> 'Responder Mensagens Privadas: Proibido.',
	'NO_AUTH_GROUP_MESSAGE'				=> 'Enviar Mensagens Privadas para Grupos: Proibido.',
	'NO_AUTH_PASSWORD_REMINDER'			=> 'Não está autorizado a pedir nova senha.',
	'NO_AUTH_READ_HOLD_MESSAGE'			=> 'Não está autorizado a ler Mensagens Privadas que estejam presas.',
	'NO_AUTH_READ_MESSAGE'				=> 'Ler Mensagens Privadas: Proibido.',
	'NO_AUTH_READ_REMOVED_MESSAGE'		=> 'Ler Mensagens Privadas apagadas pelo autor: Proibido.',
	'NO_AUTH_SEND_MESSAGE'				=> 'Enviar Mensagens Privadas: Proibido.',
	'NO_AUTH_SIGNATURE'					=> 'Definir a sua Assinatura: Proibido.',

	'NO_BCC_RECIPIENT'					=> 'Nenhum',
	'NO_BOOKMARKS'						=> 'Não tem Favoritos.',
	'NO_BOOKMARKS_SELECTED'				=> 'Não selecionou nenhum marcador.',
	'NO_EDIT_READ_MESSAGE'				=> 'A mensagem privada não pode ser editada porque já foi lida.',
	'NO_EMAIL_USER'						=> 'O Nome de Utilizador/Endereço de email indicados não foram encontrados.',
	'NO_FOES'							=> 'Não tem Inimigos definidos.',
	'NO_FRIENDS'						=> 'Não tem Amigos definidos.',
	'NO_FRIENDS_OFFLINE'				=> 'Nenhum Amigo Desligado',
	'NO_FRIENDS_ONLINE'					=> 'Nenhum Amigo Ligado',
	'NO_GROUP_SELECTED'					=> 'Nenhum Grupo especificado.',
	'NO_IMPORTANT_NEWS'					=> 'Nenhum Anúncio importante atual.',
	'NO_MESSAGE'						=> 'A Mensagem Privada selecionada não existe.',
	'NO_NEW_FOLDER_NAME'				=> 'Deve especificar um novo nome para a pasta.',
	'NO_NEWER_PM'						=> 'Nenhuma Mensagem Nova.',
	'NO_OLDER_PM'						=> 'Nenhuma Mensagem Antiga.',
	'NO_PASSWORD_SUPPLIED'				=> 'Não pode fazer entrar sem uma senha.',
	'NO_RECIPIENT'						=> 'Nenhum Destinatário Definido.',
	'NO_RULES_DEFINED'					=> 'Não há Regras Definidas.',
	'NO_SAVED_DRAFTS'					=> 'Não há rascunhos arquivados.',
	'NO_TO_RECIPIENT'					=> 'Nenhum',
	'NO_WATCHED_FORUMS'					=> 'Não está a observar nenhum Fórum.',
	'NO_WATCHED_SELECTED'				=> 'Não selecionou nenhum Tópico ou Fórum Observado.',	
	'NO_WATCHED_TOPICS'					=> 'Não está a observar nenhum Tópico.',

	'PASS_TYPE_ALPHA_EXPLAIN'			=> 'Deve ter entre %1$d e %2$d caracteres. Tem que incluir letras maiúsculas e minúsculas e números.',
	'PASS_TYPE_ANY_EXPLAIN'				=> 'Deve ter entre %1$d e %2$d caracteres.',
	'PASS_TYPE_CASE_EXPLAIN'			=> 'Deve ter entre %1$d e %2$d caracteres. Tem que incluir letras maiúsculas e minúsculas.',
	'PASS_TYPE_SYMBOL_EXPLAIN'			=> 'Deve ter entre %1$d e %2$d caracteres. Tem que incluir letras maiúsculas e minúsculas, números e símbolos.',
	'PASSWORD'							=> 'Senha',
	'PASSWORD_ACTIVATED'				=> 'A sua Nova Senha foi ativada.',
	'PASSWORD_UPDATED'					=> 'Uma nova palavra passe foi enviada para o seu endereço registado de correio eletrónico.',
	'PERMISSIONS_RESTORED'				=> 'As suas permissões originais foram restauradas com sucesso.',
	'PERMISSIONS_TRANSFERRED'			=> 'As Permissões foram transferidas do <strong>%s</strong> com sucesso. Agora, pode navegar com as Permissões do Utilizador.<br />As Permissões de Administrador não foram transferidas. Pode voltar as suas Permissões originais em qualquer momento.',
	'PM_DISABLED'						=> 'As Mensagens Privadas estão inativas.',
	'PM_FROM'							=> 'De',
	'PM_FROM_REMOVED_AUTHOR'			=> 'Esta Mensagem foi enviada por um utilizador não Registado.',
	'PM_ICON'							=> 'Ícone da Mensagem Privada',
	'PM_INBOX'							=> 'Caixa de Entrada',
	'PM_NO_USERS'						=> 'O utilizador adicionado não existe.',
	'PM_OUTBOX'							=> 'Caixa de Saída',
	'PM_SENTBOX'						=> 'Mensagens enviadas',
	'PM_SUBJECT'						=> 'Título',
	'PM_TO'								=> 'Enviar para',
	'PM_USERS_REMOVED_NO_PM'			=> 'Alguns Utilizadores adicionados estão com a função de Mensagem Privada desativada e não poderão receber a Mensagem.',
	'POPUP_ON_PM'						=> 'Abrir uma janela Pop-up quando existirem novas Mensagens Privadas',
	'POST_EDIT_PM'						=> 'Editar Mensagem',
	'POST_FORWARD_PM'					=> 'Responder Mensagem',
	'POST_NEW_PM'						=> 'Criar Mensagem',
	'POST_PM_LOCKED'					=> 'Mensagem Privada bloqueada',
	'POST_PM_POST'						=> 'Citar Mensagem',
	'POST_QUOTE_PM'						=> 'Citar Mensagem Privada',
	'POST_REPLY_PM'						=> 'Responder Mensagem Privada',
	'PRINT_PM'							=> 'Imprimir Mensagem Privada',
	'PREFERENCES_UPDATED'				=> 'As suas Preferências foram atualizadas.',
	'PROFILE_INFO_NOTICE'				=> 'Estas informações serão visíveis por todos os Utilizadores. Verifique se deseja incluir os seus dados pessoais. Todos os campos marcados com (*) são de preenchimento obrigatório.',
	'PROFILE_UPDATED'					=> 'O seu Perfil foi atualizado.',

	'RECIPIENT'							=> 'Destinatário',
	'RECIPIENTS'						=> 'Destinatários',
	'REGISTRATION'						=> 'Registo',
	'RELEASE_MESSAGES'					=> 'Clique %saqui%s para libertar as Mensagens presas, elas serão reorganizadas na pasta apropriada se houver espaço suficiente.',
	'REMOVE_ADDRESS'					=> 'Apagar endereço',
	'REMOVE_SELECTED_BOOKMARKS'			=> 'Apagar Favoritos selecionados',
	'REMOVE_SELECTED_BOOKMARKS_CONFIRM'	=> 'Tem a certeza que deseja remover todos os Favoritos selecionados?',
	'REMOVE_BOOKMARK_MARKED'			=> 'Apagar Favoritos marcados ',
	'REMOVE_FOLDER'						=> 'Remover pasta',
	'REMOVE_FOLDER_CONFIRM'				=> 'Tem a certeza que deseja remover esta pasta?',
	'RENAME'							=> 'Renomear',
	'RENAME_FOLDER'						=> 'Renomear Pasta',
	'REPLIED_MESSAGE'					=> 'Mensagens Respondidas',
	'REPLY_TO_ALL'						=> 'Responder ao remetente e a todos os destinatários.',
	'REPORT_PM'							=> 'Denunciar mensagem privada',
	'RESIGN_SELECTED'					=> 'Sair do selecionado',
	'RETURN_FOLDER'						=> 'Clique %1$sAqui%2$s para voltar à Pasta',
	'RETURN_UCP'						=> 'Clique %saqui%s para voltar ao Painel de Controlo do Utilizador',
	'RULE_ADDED'						=> 'A Regra foi adicionada com sucesso.',
	'RULE_ALREADY_DEFINED'				=> 'Esta Regra estava previamente definida.',
	'RULE_DELETED'						=> 'A Regra foi apagada com sucesso.',
	'RULE_LIMIT_REACHED'				=> 'Não pode adicionar mais regras para as mensagens privadas. Atingiu o número máximo.',
	'RULE_NOT_DEFINED'					=> 'Regra não especificada corretamente.',
	'RULE_REMOVED_MESSAGE'				=> 'Uma Mensagem Privada foi apagada pelos processos de filtragem.',
	'RULE_REMOVED_MESSAGES'				=> '%d Mensagens Privadas foram apagadas pelos processos de filtragem.',

	'SAME_PASSWORD_ERROR'				=> 'A nova Senha é igual à antiga.',
	'SEARCH_YOUR_POSTS'					=> 'Mostrar todas as minhas Mensagens',
	'SEND_PASSWORD'						=> 'Enviar Senha',
	'SENT_AT'							=> 'Enviado em',
	'SHOW_EMAIL'						=> 'Tornar visível o meu endereço de email',
	'SIGNATURE_EXPLAIN'					=> 'Escreva aqui a Assinatura que por defeito será adicionada a todas a Mensagens. O limite é de %d caracteres.',
	'SIGNATURE_PREVIEW'					=> 'Previsão da Assinatura',
	'SIGNATURE_TOO_LONG'				=> 'A sua Assinatura é muito grande.',
	'SORT'								=> 'Ordenar',
	'SORT_COMMENT'						=> 'Descrições do Ficheiro',
	'SORT_DOWNLOADS'					=> 'Transferências',
	'SORT_EXTENSION'					=> 'Extensão',
	'SORT_FILENAME'						=> 'Nome do Ficheiro',
	'SORT_POST_TIME'					=> 'Data do Anexo',
	'SORT_SIZE'							=> 'Tamanho do Ficheiro',

	'TIMEZONE'							=> 'Fuso Horário',
	'TO'								=> 'Para',
	'TOO_MANY_RECIPIENTS'				=> 'Muitos Destinatários.',
	'TOO_MANY_REGISTERS'				=> 'Excedeu o número máximo de tentativas de Registo para esta sessão. Tente novamente mais tarde.',

	'UCP'								=> 'Painel de Controlo do Utilizador',
	'UCP_ACTIVATE'						=> 'Ativar Registo',
	'UCP_ADMIN_ACTIVATE'				=> 'Tem de introduzir um endereço de email válido para que o Registo seja ativado. O Administrador verificará o seu Registo, e, se for Aprovado, receberá um email para ativar a sua conta.',
	'UCP_AIM'							=> 'Mensageiro Instantâneo AOL',
	'UCP_ATTACHMENTS'					=> 'Anexos',
	'UCP_COPPA_BEFORE'					=> 'Tenho mais de 13 anos. Nasci antes de %s.',
	'UCP_COPPA_ON_AFTER'				=> 'Tenho menos de 13 anos. Nasci depois de %s.',
	'UCP_EMAIL_ACTIVATE'				=> 'Tem que usar um email válido. Após o Registo receberá um email para Ativação da sua conta. Só depois de receber esse email e Ativar a Conta é que poderá entrar no Fórum.',
	'UCP_ICQ'							=> 'Número de ICQ',
	'UCP_JABBER'						=> 'Endereço Jabber',

	'UCP_MAIN'							=> 'Geral',
	'UCP_MAIN_ATTACHMENTS'				=> 'Anexos',
	'UCP_MAIN_BOOKMARKS'				=> 'Administrar Favoritos',
	'UCP_MAIN_DRAFTS'					=> 'Rascunhos Arquivados',
	'UCP_MAIN_FRONT'					=> 'Página Principal',
	'UCP_MAIN_SUBSCRIBED'				=> 'Administrar Observações',

	'UCP_MSNM'							=> 'MSN Messenger',
	'UCP_NO_ATTACHMENTS'				=> 'Não enviou nenhum anexo.',

	'UCP_PREFS'							=> 'Preferências',
	'UCP_PREFS_PERSONAL'				=> 'Configurações Pessoais',
	'UCP_PREFS_POST'					=> 'Mensagens enviadas',
	'UCP_PREFS_VIEW'					=> 'A ver Mensagens',

	'UCP_PM'							=> 'Mensagens Privadas',
	'UCP_PM_COMPOSE'					=> 'Criar Mensagem Privada',
	'UCP_PM_DRAFTS'						=> 'Rascunhos',
	'UCP_PM_OPTIONS'					=> 'Opções',
	'UCP_PM_POPUP'						=> 'Mensagens Privadas',
	'UCP_PM_POPUP_TITLE'				=> 'Pop-up de Mensagens Privadas',
	'UCP_PM_UNREAD'						=> 'Mensagens não lidas',
	'UCP_PM_VIEW'						=> 'Ver Mensagens',

	'UCP_PROFILE'						=> 'Perfil',
	'UCP_PROFILE_AVATAR'				=> 'O seu Avatar',
	'UCP_PROFILE_PROFILE_INFO'			=> 'O seu Perfil',
	'UCP_PROFILE_REG_DETAILS'			=> 'Detalhes do seu Registo',
	'UCP_PROFILE_SIGNATURE'				=> 'A sua assinatura',

	'UCP_USERGROUPS'					=> 'Grupos de Utilizadores',
	'UCP_USERGROUPS_MEMBER'				=> 'Editar Inscrições em Grupos',
	'UCP_USERGROUPS_MANAGE'				=> 'Administrar Grupos',

	'UCP_REGISTER_DISABLE'				=> 'Não é possível criar novos Registos.',
	'UCP_REMIND'						=> 'Enviar Senha',
	'UCP_RESEND'						=> 'Enviar email de Ativação',
	'UCP_WELCOME'						=> 'Bem-vindo ao Painel de Controlo do Utilizador. Aqui pode ver e atualizar o seu Perfil, as suas Preferências, observar Fóruns e Tópicos. Pode enviar Mensagens a outros Utilizadores (se permitido). Verifique se leu todos os anúncios.',
	'UCP_YIM'							=> 'Yahoo! Messenger',
	'UCP_ZEBRA'							=> 'Amigos e Inimigos',
	'UCP_ZEBRA_FOES'					=> 'Inimigos',
	'UCP_ZEBRA_FRIENDS'					=> 'Amigos',
	'UNDISCLOSED_RECIPIENT'				=> 'Sem destinatário',
	'UNKNOWN_FOLDER'					=> 'Pasta Desconhecida',
	'UNWATCH_MARKED'					=> 'Parar de observar marcados',
	'UPLOAD_AVATAR_FILE'				=> 'Enviar do seu Computador',
	'UPLOAD_AVATAR_URL'					=> 'Enviar de uma URL',
	'UPLOAD_AVATAR_URL_EXPLAIN'			=> 'Insira a URL da imagem que pretende usar no Fórum.',
	'USERNAME_ALPHA_ONLY_EXPLAIN'		=> 'O Nome de Utilizador deve ser constituído por %1$d a %2$d caracteres e usar somente caracteres alfanuméricos.',
	'USERNAME_ALPHA_SPACERS_EXPLAIN'	=> 'O Nome de Utilizador deve ser constituído por %1$d a %2$d caracteres e usar caracteres alfanuméricos, espaço ou -+_[].',
	'USERNAME_ASCII_EXPLAIN'			=> 'O Nome de Utilizador deve ser constituído por %1$d a %2$d caracteres e deve conter somente caracteres ASCII, sendo assim, sem símbolos especiais.',
	'USERNAME_LETTER_NUM_EXPLAIN'		=> 'O Nome de Utilizador deve ser constituído por %1$d a %2$d caracteres e deve conter somente letras ou números.',
	'USERNAME_LETTER_NUM_SPACERS_EXPLAIN'	=> 'O Nome de utilizador deve ser constituído por %1$d a %2$d caracteres e deve conter letras, números, espaço ou +-[].',
	'USERNAME_CHARS_ANY_EXPLAIN'		=> 'O Nome de Utilizador deve ser constituído por %1$d a %2$d caracteres.',
	'USERNAME_TAKEN_USERNAME'			=> 'O Nome de utilizador que escolheu já existe.',
	'USERNAME_DISALLOWED_USERNAME'		=> 'O Nome de Utilizador que escolheu foi proibido ou contém uma palavra censurada. Escolha um nome diferente.',
	'USER_NOT_FOUND_OR_INACTIVE'		=> 'O Nome de utilizador que escreveu não pode ser encontrado ou está inativo.',

	'VIEW_AVATARS'						=> 'Mostrar Avatares',
	'VIEW_EDIT'							=> 'Ver/Editar',
	'VIEW_FLASH'						=> 'Mostrar Animações em Flash',
	'VIEW_IMAGES'						=> 'Mostrar imagens nas Mensagens',
	'VIEW_NEXT_HISTORY'					=> 'Próxima MP no histórico',
	'VIEW_NEXT_PM'						=> 'Próxima MP',
	'VIEW_PM'							=> 'Ver Mensagem',
	'VIEW_PM_INFO'						=> 'Detalhes da Mensagem',
	'VIEW_PM_MESSAGE'					=> '1 Mensagem',
	'VIEW_PM_MESSAGES'					=> '%d Mensagens',
	'VIEW_PREVIOUS_HISTORY'				=> 'MP Anterior no histórico',
	'VIEW_PREVIOUS_PM'					=> 'MP Anterior',
	'VIEW_SIGS'							=> 'Mostrar Assinaturas',
	'VIEW_SMILIES'						=> 'Mostrar Emoções como Imagens',
	'VIEW_TOPICS_DAYS'					=> 'Mostrar Tópicos do dia anterior',
	'VIEW_TOPICS_DIR'					=> 'Mostrar Tópicos Ordenados por direção',
	'VIEW_TOPICS_KEY'					=> 'Mostrar Tópicos Ordenados por',
	'VIEW_POSTS_DAYS'					=> 'Mostrar Mensagens do dia anterior',
	'VIEW_POSTS_DIR'					=> 'Mostrar Mensagens Ordenados por direção',
	'VIEW_POSTS_KEY'					=> 'Mostrar Mensagens Ordenadas por',

	'WATCHED_EXPLAIN'					=> 'Esta é a lista de Fóruns e Tópicos que está a observar. Será avisado de novas Mensagens em cada um deles. Para cancelar a observação, marque o Fórum ou Tópico e então pressione o botão Parar de observar marcados.',
	'WATCHED_FORUMS'					=> 'Fóruns observados',
	'WATCHED_TOPICS'					=> 'Tópicos observados',
	'WRONG_ACTIVATION'					=> 'O código de Ativação que forneceu não confere com o Banco de Dados.',

	'YOUR_DETAILS'						=> 'A sua Atividade',
	'YOUR_FOES'							=> 'Os Seus Inimigos',
	'YOUR_FOES_EXPLAIN'					=> 'Para apagar Utilizadores, selecione-os e clique em enviar.',
	'YOUR_FRIENDS'						=> 'Os Seus Amigos',
	'YOUR_FRIENDS_EXPLAIN'				=> 'Para apagar os Utilizadores, selecione-os e clique em enviar.',
	'YOUR_WARNINGS'						=> 'Seu Nível de Advertência',

	'PM_ACTION'	=> array(
		'PLACE_INTO_FOLDER'				=> 'Colocar na Pasta',
		'MARK_AS_READ'					=> 'Marcar como Lida',
		'MARK_AS_IMPORTANT'				=> 'Marcar como Importante',
		'DELETE_MESSAGE'				=> 'Apagar a Mensagem',
	),
	'PM_CHECK'							=> array(
		'SUBJECT'						=> 'Assunto',
		'SENDER'						=> 'De',
		'MESSAGE'						=> 'Mensagem',
		'STATUS'						=> 'Estado da Mensagem',
		'TO'							=> 'Para',
	),
	'PM_RULE'							=> array(
		'IS_LIKE'						=> 'Está como',
		'IS_NOT_LIKE'					=> 'Não está como',
		'IS'							=> 'é',
		'IS_NOT'						=> 'Não é',
		'BEGINS_WITH'					=> 'Inicia com',
		'ENDS_WITH'						=> 'Conclui com',
		'IS_FRIEND'						=> 'é Amigo',
		'IS_FOE'						=> 'é Inimigo',
		'IS_USER'						=> 'é Utilizador',
		'IS_GROUP'						=> 'Está no Grupo de Utilizadores',
		'ANSWERED'						=> 'Respondido',
		'FORWARDED'						=> 'Reencaminhado',
		'TO_GROUP'						=> 'Para Grupo',
		'TO_ME'							=> 'Para mim',
	),


	'GROUPS_EXPLAIN'					=> 'Os Grupos de Utilizadores permitem melhorar a gestão dos membros do Fórum. Logo de inicio será colocado num grupo especifico, que será o seu Grupo Padrão. Este grupo define como poderá aparecer aos outros utilizadores, por exemplo a cor do seu Nome, Avatar, Classificação, etc. Dependendo de como o administrador o definiu, poderá ser-lhe permitido alterar o seu grupo Padrão. Poderá também ser mudado de Grupo ou ser-lhe permitido juntar-se a outros Grupos. Alguns grupos poderão dar-lhe permissões adicionais para ver outros conteúdos ou ter capacidades acrescidas.',
	'GROUP_LEADER'						=> 'Liderança',
	'GROUP_MEMBER'						=> 'Inscrito',
	'GROUP_PENDING'						=> 'Inscrição pendente',
	'GROUP_NONMEMBER'					=> 'Não Inscrito',
	'GROUP_DETAILS'						=> 'Informações do Grupo',

	'NO_LEADER'							=> 'Este Grupo não tem Lideres',
	'NO_MEMBER'							=> 'Este Grupo não tem Utilizadores',
	'NO_PENDING'						=> 'Este Grupo não tem Utilizadores Pendentes',
	'NO_NONMEMBER'						=> 'Nenhum Grupo de Visitantes',
));

?>